==> micrometer-core-1.0.0-rc.8-sources.jar: io/micrometer/core/instrument/noop/NoopDistributionSummary.java <==
/**
 * Copyright 2017 Pivotal Software, Inc.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micrometer.core.instrument.noop;

import io.micrometer.core.instrument.DistributionSummary;
import io.micrometer.core.instrument.HistogramSnapshot;

public class NoopDistributionSummary extends NoopMeter implements DistributionSummary {
    public NoopDistributionSummary(Id id) {
        super(id);
    }

    @Override
    public void record(double amount) {
    }

    @Override
    public long count() {
        return 0;
    }

    @Override
    public double totalAmount() {
        return 0;
    }

    @Override
    public double max() {
        return 0;
    }

    @Override
    public double percentile(double percentile) {
        return 0;
    }

    @Override
    public double histogramCountAtValue(long value) {
        return 0;
    }

    @Override
    public HistogramSnapshot takeSnapshot(boolean supportsAggregablePercentiles) {
        return HistogramSnapshot.empty();
    }
}

==> micrometer-core-1.0.2-sources.jar: io/micrometer/core/instrument/noop/NoopDistributionSummary.java <==
/**
 * Copyright 2017 Pivotal Software, Inc.
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micrometer.core.instrument.noop;

import io.micrometer.core.instrument.DistributionSummary;
import io.micrometer.core.instrument.distribution.HistogramSnapshot;

public class NoopDistributionSummary extends NoopMeter implements DistributionSummary {
    public NoopDistributionSummary(Id id) {
        super(id);
    }

    @Override
    public void record(double amount) {
    }

    @Override
    public long count() {
        return 0;
    }

    @Override
    public double totalAmount() {
        return 0;
    }

    @Override
    public double max() {
        return 0;
    }

    @Override
    public double percentile(double percentile) {
        return 0;
    }

    @Override
    public double histogramCountAtValue(long value) {
        return 0;
    }

    @Override
    public HistogramSnapshot takeSnapshot(boolean supportsAggregablePercentiles) {
        return HistogramSnapshot.empty();
    }
}
